@@ -69,7 +69,7 @@ public class BootstrapPage {
 		counters = new Vector<String>();
 		numbDefinition = numberingDefinition;
 		jscodes.add("$(document).ready(function() {$('.tip').tooltip();});var raphael_tooltip = $('#gtooltip').hide();var tooltipHTML = '';var tooltipOVER = false;$(document).mousemove(function(e){if (tooltipOVER){raphael_tooltip.css('left', e.pageX+20).css('top', e.pageY+20);raphael_tooltip.html(tooltipHTML);}});function addTip(node, txt){$(node).mouseenter(function(){tooltipHTML = txt;raphael_tooltip.fadeIn();tooltipOVER = true;}).mouseleave(function(){raphael_tooltip.fadeOut(200);tooltipOVER = false;});}");
-		csscodes.add("#gtooltip{position:absolute;border:1px solid gray;background-color:white;z-index:1000;max-width:400px;};.tip::before{counter-increment:counter-tip;content:\"*\";vertical-align:super;};");
+		csscodes.add("#gtooltip{position:absolute;border:1px solid gray;background-color:white;z-index:1000;max-width:400px;}.tip::before{counter-increment:counter-tip;content:\"*\";vertical-align:super;}");
 		footer = new LinkedList<ParagraphSet>();
 		headerMenu = null;
 		description = desc;
