@@ -207,8 +207,12 @@ public class SlideContent {
 		
 		img.setPPTXMLPackage(itsPPTX.getBaseDocument());
 		img.setPPTXSlidePart(slidePart);
+		long X = layoutDescription.getContent(num_shape).getXfrm().getOff().getX();
+		long Y = layoutDescription.getContent(num_shape).getXfrm().getOff().getY();
+		
+		img.setOff(X, Y);
+		img.setExt(img.getCx(), img.getCy());
 
-		img.setXfrm(layoutDescription.getContent(num_shape).getXfrm());
 		img.setUID(uidShape+1);
 		img.setShapeID(uidShape+1);
 		addIMG( img );
@@ -346,7 +350,7 @@ public class SlideContent {
 		return noproblem;
 	}
 	private void incr_ol_id(ParagraphSet obj){
-		if( obj.getParProperties().getListStyle().equals("ordered") && obj.getParProperties().getLevel() < 2 ){
+		if( obj.getParProperties() != null && obj.getParProperties().getListStyle().equals("ordered") && obj.getParProperties().getLevel() < 2 ){
 			ol_id = ol_id + obj.size();
 		}
 	}
@@ -365,9 +369,11 @@ public class SlideContent {
 		
 		if( restartNumbering ) init_ol_id();
 		
-		slidePart.getJaxbElement().getCSld().getSpTree()
-		.getSpOrGrpSpOrGraphicFrame().add(obj.get_pptx_elt(itsPPTX.getNumberingDefinition(), ol_id));
-		
+		Shape s =  obj.get_pptx_elt(itsPPTX.getNumberingDefinition(), ol_id);
+		if( layoutDescription.getContent(num_shape).isList() && obj.getParProperties() == null )
+			s.getTxBody().setLstStyle(layoutDescription.getContent(num_shape).getListStyle());
+
+		slidePart.getJaxbElement().getCSld().getSpTree().getSpOrGrpSpOrGraphicFrame().add(s);
 		num_shape++;
 		uidShape++;
 
