@@ -1,3 +1,11 @@
+/*
+ * This file is part of ReporteRs
+ * Copyright (c) 2014, David Gohel All rights reserved.
+ * This program is licensed under the GNU GENERAL PUBLIC LICENSE V3.
+ * You may obtain a copy of the License at :
+ * http://www.gnu.org/licenses/gpl.html
+ */
+
 package org.lysis.reporters.img;
 
 import java.io.File;
@@ -21,8 +29,11 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 	// for docx and pptx
 	private byte[] image_bytes;
 	private String filename;
-	private int width_px;
-	private int height_px;
+
+	private float width_in;
+	private float height_in;
+	private long width_emu;
+	private long height_emu;
 	
 
 	static private String PICTURE = 
@@ -53,44 +64,40 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 		    + "</p:spPr>"
 		  + "</p:pic>";
 
-	public Image(String filename) throws Exception {
+	public Image(String filename, int ppi) throws Exception {
+		super();
+		this.filename = filename;
+		
+		File file = new File(filename);
+		image_bytes = org.lysis.reporters.img.Imageutils.convertImageToByteArray(file);
+		if( !filename.toLowerCase().endsWith(".wmf") && !filename.toLowerCase().endsWith(".emf") ) {
+			float[] dims = org.lysis.reporters.img.Imageutils.getImageInfo(file, ppi);
+			setDim(dims[0], dims[1]);
+		} 
+	}
+	
+	public Image(String filename, float w, float h) throws Exception {
 		super();
 		
 		this.filename = filename;
 		
 		File file = new File(filename);
 		image_bytes = org.lysis.reporters.img.Imageutils.convertImageToByteArray(file);
-		int[] dims = org.lysis.reporters.img.Imageutils.getDimensions(image_bytes);
-	
-		int physicalWidthDpi = dims[2];
-		int physicalHeightDpi = dims[3];
-		
-		double width_emu = dims[0] * 72 * 12700 ;width_emu = width_emu  / physicalWidthDpi ;
-		double height_emu = dims[1] * 72 * 12700;height_emu = height_emu / physicalHeightDpi;
-		this.setExt((long)width_emu, (long)height_emu);
-		
+		setDim(w, h);
 	}
 	
-	public Image(String filename, double w, double h) throws Exception {
-		super();
-		
-		this.filename = filename;
-		
-		File file = new File(filename);
-		image_bytes = org.lysis.reporters.img.Imageutils.convertImageToByteArray(file);
-		
-		
-		double width_emu = w * 72 * 12700 ;
-		double height_emu = h * 72 * 12700;
-		this.setExt((long)width_emu, (long)height_emu);
-		
-	}
 	public long nextUniqueId(){
 		return unique_id+2;
 	}
-	public void setDim(int w, int h){
-		width_px = w;
-		height_px = h;
+	
+	public void setDim(double w, double h){
+		width_in = (float)w;
+		height_in = (float)h;
+		width_emu = (long)(width_in * 914400);
+		height_emu = (long)(height_in * 914400);
+//		System.out.println("width_in:" + width_in + " - height_in: " + height_in );
+//		System.out.println("width_emu:" + width_emu + " - height_emu: " + height_emu );
+		this.setExt(width_emu, height_emu);
 	}
 
 
@@ -144,7 +151,7 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 		
 		out += pStart + "<img src=\"data:image/png;base64," 
 			+ new String( org.apache.commons.codec.binary.Base64.encodeBase64(image_bytes) ) 
-			+ "\" width=\"" + width_px + "\" height=\"" + height_px + "\">" + pStop;
+			+ "\" width=\"" + (int)(width_in*72) + "\" height=\"" + (int)(height_in*72) + "\">" + pStop;
 		return out;
 	}
 
@@ -172,4 +179,5 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 	public boolean hasHTML() {
 		return true;
 	}
+
 }
