@@ -2,10 +2,6 @@
  * This file is part of ReporteRs.
  * Copyright (c) 2014, David Gohel All rights reserved.
  *
- * It is inspired from sources of R package grDevices:
- * Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- * Copyright (C) 1998--2014  The R Core Team
- *
  * ReporteRs is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -38,5 +34,6 @@ extern "C" {
 	void add_popup(int *dn, int *id, char **str, int *l);
 	void add_click(int *dn, int *id, char **str, int *l);
 	void add_dblclick(int *dn, int *id, char **str, int *l);
+	void add_post_commands( int *dn, int *id, char **str, int *l);
+	void trigger_last_post_commands( int *dn );
 }
-
